@import "../../../css/_mixins.scss";
@import "../../../css/_trx_addons.vars.scss";

//@mixin sc_supertitle--sm() {
@media #{$media_sm} {

	.sc_supertitle .sc_supertitle_icon_empty_column,
	.sc_supertitle .sc_supertitle_no_icon {
		position: absolute;
		left: 0;
	}

	.sc_supertitle .sc_supertitle_media_block {
		background-color: transparent!important;
	}

	.sc_supertitle .sc_supertitle_icon_empty_column {
		padding-left: 0;
		padding-bottom: inherit;
		top: 0;
		bottom: 20px;
	}
	.sc_supertitle_columns_wrap > [class*="trx_addons_column-"] {
		padding-left: 2rem;
	}

	.sc_supertitle_columns_wrap.trx_addons_columns_wrap {
		display: block;
	}
}
